//		Parametric project box and box lid
//
//		Make a project box and matching lid (separate calls) which encloses a cavity of the size specified.
//		Each corner (of both the box and lid) has a hole for a screw to lock the lid on the box
//
$fn=30;                                                                                             // Smooth curves
//
//		length = inside length of box
//		width = inside width of box
//		height = inside height of box
//		thickness = thickness of all walls and lid
//
length = 150;
width = 75;
height = 25;
thickness = 3;
screwSize = 3;
//
WY_ProjectBox( length,width,height,thickness );
translate([0,width+15,0])
    WY_ProjectBoxLid( length,width,thickness );
//
//
//		Make a project box of the desired internal size
//
module WY_ProjectBox (length,width,height,thickness=3) {
	difference () {
	union () {
			//
			//		Make a cube for outside of the box 2 x thickness wider and longer and 1 x thickness higher
			//		Then relocate to [thickness,thickness,thickness] and remove a box of the desired size
			//		The remaining carcass is the project box
			//
			difference() {
				cube ( [length+2*thickness,width+2*thickness,height+thickness] ) ; 				    // Outside of box
				translate ( [thickness,thickness,thickness] ) {cube ( [length,width,height+1] );};	// Inside of box
			};
			//
			//		Add a support in each corner to attach the lid. We're using an inverted cone to try to prevent
			//			the printer fro requiring any support mmaterial. It's too hard to get out of the inside of
			//			the box after it's made.
			//
			translate ( [thickness,thickness,thickness] ) { cylinder(h=height,r1=0,r2=thickness); };
			translate ( [thickness+length,thickness,thickness] ) {cylinder(h=height,r1=0,r2=thickness); };
			translate ( [thickness+length,thickness+width,thickness] ) {cylinder(h=height,r1=0,r2=thickness); };
			translate ( [thickness,thickness+width,thickness] ) {cylinder(h=height,r1=0,r2=thickness); };
		};
		//
		//		Drill holes in each corner of the box
		//
		translate ( [thickness,thickness,height-2*thickness] ) { cylinder(h=3*thickness+1,d=screwSize); };
		translate ( [thickness+length,thickness,height-2*thickness] ) {cylinder(h=3*thickness+1,d=screwSize); };
		translate ( [thickness+length,thickness+width,height-2*thickness] ) {cylinder(h=3*thickness+1,d=screwSize); };
		translate ( [thickness,thickness+width,height-2*thickness] ) {cylinder(h=3*thickness+1,d=screwSize); };		
	};
};
//
//		Now make a lid for the box
//
module WY_ProjectBoxLid (length,width,thickness=3) {
		double = 2*thickness;
		difference() {
			cube ([length+double,width+double,thickness]);											   // Lid
			//
			//		Drill holes in corners
			//
			translate( [thickness,thickness,-0.5*thickness] ) { cylinder(h=double,d=screwSize); };
			translate( [thickness+length,thickness,-0.5*thickness] ) { cylinder(h=double,d=screwSize); };
			translate( [thickness+length,thickness+width,-0.5*thickness] ) { cylinder(h=double,d=screwSize); };
			translate( [thickness,thickness+width,-0.5*thickness] ) { cylinder(h=double,d=screwSize); };
		};
};

